UdtRawDatagramRuntimeTarget class final
Live runtime target backed by RawDatagramSocket.bind + connect.
This target also implements UdtSocketOptionTarget so runtime plans can be built and then applied through one shared socket adapter boundary.
- Implemented types
Constructors
- UdtRawDatagramRuntimeTarget({int localPort = 0, InternetAddress? ipv4BindAddress, InternetAddress? ipv6BindAddress, InternetAddress? ipv4RemoteAddress, InternetAddress? ipv6RemoteAddress, int remotePort = 0, bool supportsReceiveSendBufferSizing = false, bool supportsIpv6OnlyOption = true})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipv4BindAddress → InternetAddress
-
final
- ipv4RemoteAddress → InternetAddress?
-
final
- ipv6BindAddress → InternetAddress
-
final
- ipv6RemoteAddress → InternetAddress?
-
final
- localPort → int
-
final
- remotePort → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socket → RawDatagramSocket?
-
no setter
- supportsIpv6OnlyOption → bool
-
final
- supportsReceiveSendBufferSizing → bool
-
final
Methods
-
bind(
UdtBindFamily family, {required bool dualStack}) → Future< void> -
override
-
close(
) → Future< void> -
override
-
connect(
UdtEndpointFamily family) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIpv6Only(
bool enabled) → Future< void> -
override
-
setReceiveBufferBytes(
int bytes) → Future< void> -
override
-
setReuseAddress(
bool enabled) → Future< void> -
override
-
setReusePort(
bool enabled) → Future< void> -
override
-
setSendBufferBytes(
int bytes) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited