UdtSocketRuntimeExecutionReport class final
Constructors
-
UdtSocketRuntimeExecutionReport({required List<
UdtBindAttemptResult> attempts, required UdtBindPlan? selectedPlan}) -
const
Properties
-
attempts
→ List<
UdtBindAttemptResult> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBound → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedPlan → UdtBindPlan?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited