UdtPacketTimeWindow class final
Pure-Dart packet/probe timing window ported from upstream
window.h/window.cpp CPktTimeWindow.
Constructors
- UdtPacketTimeWindow({required UdtProtocolClock clock, int arrivalWindowSize = 16, int probeWindowSize = 16})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minPacketSendIntervalMicros → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBandwidthPacketsPerSecond(
) → int -
getPacketReceiveSpeedPacketsPerSecond(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPacketArrival(
) → void -
onPacketSent(
int currentTimeMicros) → void -
probe1Arrival(
) → void -
probe2Arrival(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited