UdtSocketRuntimeExecutor class final
Deterministic bind executor that walks runtime bind plans with fallback.
This remains socket-I/O agnostic and works with UdtSocketRuntimeTarget adapters for deterministic tests and later real runtime wiring.
Constructors
- UdtSocketRuntimeExecutor()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeBindPlan(
{required UdtSocketRuntimeTarget target, required UdtSocketRuntimePlan runtimePlan}) → Future< UdtSocketRuntimeExecutionReport> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited